@@ -1,11 +1,11 @@
 
 from .reflection import Reflect, VersionReflect
 from .call import Call, VersionCall
-from .exception import CallError, Redirect, CallStop
+from .exception import CallError, Redirect, CallStop, AccessDenied
 from .http import Request, Response
 from .utils import AcceptHeader
 from .core import Controller, CorsMixin
 from . import decorators
 
-__version__ = '0.8.5'
+__version__ = '0.8.6'
 
